@@ -8,24 +8,23 @@
 #' eigenvalues , such values will be used to
 #' compute their spectral density.
 #'
-#' @param k the number of clusters.
+#' @param k the number of clusters. If NULL, it won't return the computed clustering.
 #'
 #' @param clus_method the agglomeration method to be used. This should be (an
-#' unambiguous abbreviation of) one of '"ward.D"', '"ward.D2"', '"single"',
-#' '"complete"', '"average"' (= UPGMA), '"mcquitty"' (= WPGMA), '"median"'
-#' (= WPGMC) or '"centroid"' (= UPGMC).
+#' unambiguous abbreviation of) one of ''ward.D'', ''ward.D2'', ''single'',
+#' ''complete'', ''average'' (= UPGMA), ''mcquitty'' (= WPGMA), ''median''
+#' (= WPGMC) or ''centroid'' (= UPGMC).
 #'
-#' @param dist string indicating if you want to use the "JS" (default), "L1" or "L2"
-#' distances. "JS" means Jensen-Shannon divergence.
+#' @param dist string indicating if you want to use the 'JS' (default), 'L1' or 'L2'
+#' distances. 'JS' means Jensen-Shannon divergence.
 #'
 #' @param ... Other relevant parameters for \code{\link{graph.spectral.density}}.
 #'
 #'
-#' @return A list containing:
-#' \item{\code{hclust:}}{ an object of class \code{hclust} which describes the tree produced
-#' by the clustering process.}
-#' \item{\code{cluster:}}{ the clustering labels for each graph.}
-#'
+#' @return A list containing the following elements:
+#' \item{\code{hclust}:}{ A class of type 'hclust'.}
+#' \item{\code{cluster:}}{ A vector of the same length of \code{Graphs} containing the
+#' clusterization labels.}
 #'
 #' @keywords clustering
 #'
@@ -62,19 +61,21 @@
 #' @import stats
 #' @import methods
 #' @export
-graph.hclust <- function(Graphs, k, clus_method="complete", dist = "JS", ...) {
+graph.hclust <- function(Graphs, k = NULL, clus_method = "complete", dist = "JS", ...) {
 
-  if(!valid.input(Graphs,level = 1)) stop("The input should be a list of igraph objects!")
+    if (!valid.input(Graphs, level = 1))
+        stop("The input should be a list of igraph objects!")
 
-  Graphs <- set.list.spectral.density(Graphs,...)
+    Graphs <- set.list.spectral.density(Graphs, ...)
 
-  d <- graph.dist(Graphs,dist = dist)
+    d <- graph.dist(Graphs, dist = dist)
 
-  tmp <- hclust(as.dist(d), method=clus_method)
+    tmp <- hclust(as.dist(d), method = clus_method)
 
-  res <- list()
-  res$hclust <- tmp
-  res$cluster <- cutree(tmp, k)
-
-  return(res)
+    res <- list()
+    res$hclust <- tmp
+    if (!is.null(k)) {
+        res$cluster <- cutree(tmp, k)
+    }
+    return(res)
 }
